@@ -15,6 +15,7 @@ import keyring
 from .clevergui import start_gui, button_menu, text_input
 from .cleverutils import to_json, timer
 from .cleverwebutils import Login_to
+import threading
 
 class CleverSession(CleverDict):
     """
@@ -101,25 +102,6 @@ class CleverSession(CleverDict):
         """
         keyring.delete_password(CleverSession.choices[self.url], self.username)
 
-    # @timer
-    # def login_with_webbrowser(self, **kwargs):
-    #     """
-    #     KWARGS:
-
-    #     wait : Seconds for selenium to implicitly_wait
-    #     """
-    #     self.check_and_prompt("url", "username", "password")
-    #     self.browser = webdriver.Chrome()
-    #     self.browser.implicitly_wait(kwargs.get("wait") or 3)
-    #     self.browser.get(self.url)
-    #     dispatch = {"github.com": Login_to.github,
-    #                 "twitter.com": Login_to.twitter,
-    #                 "satchelone.com": Login_to.satchelone}
-    #     for website, func in dispatch.items():
-    #         if website in self.url:
-    #             func(self)
-    #             break
-
     @timer
     def login_with_webbrowsers(self, **kwargs):
         """
